
TODO_49_31_47_63:
Add `query_enum_items_func` internal command to do exactly the same what Ctrl+Alt+Q does, but via Invocation.

Rename to `query_enum_items_func` (with `SpecialFunc.query_enum_items_func` as `func_id`).

See also: FS_02_25_41_81 / query_enum_items_func
